<?xml version="1.0" encoding="utf-8" ?>

<!-- ECB/SIS Public License, version 1.0, document reference SIS/2001/116

Copyright (C) 2006, European Central Bank. All rights reserved.

Redistribution and use in source and binary forms,
with or without modification, are permitted
provided that the following conditions are met:

Redistributions of source code must retain the above copyright notice,
this list of conditions and the following disclaimer.
Redistributions in binary form must reproduce the above copyright notice,
this list of conditions and the following disclaimer in the documentation
and/or other materials provided with the distribution.
Neither the name of the European Central Bank
nor the names of its contributors may be used to endorse or promote products
derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
HOLDERS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-->

<xsl:stylesheet
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:message="http://www.SDMX.org/resources/SDMXML/schemas/v2_0/message"
	xmlns:structure="http://www.SDMX.org/resources/SDMXML/schemas/v2_0/structure"
	xmlns:exr="http://www.ecb.int/vocabulary/stats/exr/1"	
	version="1.0"
	exclude-result-prefixes="message exr xsl"
>
 
    <!--  Output related settings -->
    <xsl:output 
    	method="xml"
		indent="yes"
		omit-xml-declaration="yes"
		encoding="UTF-8"
		version="1.0"
		media-type="application/xml"/>
    <xsl:strip-space elements="*"/>
    
    <!-- Period (e.g.: 2006-11-21) -->
    <xsl:param name="period"/>
    
    <!-- List of currencies from the structure file so that we can print the
    currency name -->
    <xsl:variable
		name="currencies"
		select="document('ecb_exr1_structure.xml')/*[local-name()='Structure']/message:CodeLists/structure:CodeList[@id='CL_CURRENCY']"/>
    
    <xsl:template match="/">
    	<html lang="en" xmlns="http://www.w3.org/1999/xhtml" xml:lang="en">
    	<head>
    		<title>Euro foreign exchange reference rates at: <xsl:value-of select="$period"/></title>
    		<meta http-equiv="content-type" content="text/html; charset=utf-8" />
			<meta http-equiv="content-language" content="en" />
    	</head>
    	<body>
	    <table>
			<caption>Euro foreign exchange reference rates at: <xsl:value-of select="$period"/></caption>
			<thead>
				<tr><th>Currency</th><th>Spot</th></tr>
			</thead>
			<tbody>
				<xsl:apply-templates select="message:CompactData/exr:DataSet/exr:Series"/>
    		</tbody>
		</table>
		</body>
		</html>
    </xsl:template>
    
    <xsl:template match="exr:Series">
		<xsl:variable name="currency" select="@CURRENCY"/>
		<tr>
    		<td><xsl:value-of select="$currencies/structure:Code[@value = $currency]/structure:Description"/> (<xsl:value-of select="@CURRENCY"/>)</td>
   			<td><xsl:apply-templates select="exr:Obs"/></td>
    	</tr>
    </xsl:template>
    
    <xsl:template match="exr:Obs">
    	<xsl:if test="@TIME_PERIOD = $period"><xsl:value-of select="@OBS_VALUE"/></xsl:if>
    </xsl:template>    
</xsl:stylesheet>
